@@ -81,8 +81,14 @@ bool CFileSystem::fileIsValid(const FileData* mod,
 	return true;
 }
 
-bool CFileSystem::parseSdp(const std::string& filename,
-			   std::list<FileData*>& files)
+std::string getMD5fromFilename(const std::string& path)
+{
+	const size_t start = path.rfind(PATH_DELIMITER) + 1;
+	const size_t end = path.find(".", start);
+	return path.substr(start, end-start);
+}
+
+bool CFileSystem::parseSdp(const std::string& filename, std::list<FileData>& files)
 {
 	char c_name[255];
 	unsigned char c_md5[16];
@@ -94,16 +100,21 @@ bool CFileSystem::parseSdp(const std::string& filename,
 	gzFile in = gzdopen(fileno(f), "rb");
 	if (in == Z_NULL) {
 		LOG_ERROR("Could not open %s", filename.c_str());
+		fclose(f);
 		return false;
 	}
 	files.clear();
+	HashMD5 sdpmd5;
+	sdpmd5.Init();
 	while (true) {
+
 		if (!gzread(in, &length, 1)) {
 			if (gzeof(in)) {
 				break;
 			}
 			LOG_ERROR("Unexpected eof in %s", filename.c_str());
 			gzclose(in);
+			fclose(f);
 			return false;
 		}
 		if (!((gzread(in, &c_name, length)) && (gzread(in, &c_md5, 16)) &&
@@ -113,15 +124,31 @@ bool CFileSystem::parseSdp(const std::string& filename,
 			fclose(f);
 			return false;
 		}
-		FileData* f = new FileData;
-		f->name = std::string(c_name, length);
-		memcpy(f->md5, &c_md5, 16);
-		memcpy(f->crc32, &c_crc32, 4);
-		f->size = parse_int32(c_size);
-		files.push_back(f);
+		FileData fd;
+		fd.name = std::string(c_name, length);
+		memcpy(fd.md5, &c_md5, 16);
+		memcpy(fd.crc32, &c_crc32, 4);
+		fd.size = parse_int32(c_size);
+		files.push_back(fd);
+		
+		HashMD5 nameMd5;
+		nameMd5.Init();
+		nameMd5.Update(fd.name.data(), fd.name.size());
+		nameMd5.Final();
+		assert(nameMd5.getSize() == 16);
+		assert(sizeof(fd.md5) == 16);
+		sdpmd5.Update((const char*)nameMd5.Data(), nameMd5.getSize());
+		sdpmd5.Update((const char*)&fd.md5[0], sizeof(fd.md5));
 	}
 	gzclose(in);
 	fclose(f);
+	sdpmd5.Final();
+	const std::string filehash = getMD5fromFilename(filename);
+	if (filehash != sdpmd5.toString()) {
+		LOG_ERROR("%s is invalid, deleted (%s vs %s)", filename.c_str(), filehash.c_str(), sdpmd5.toString().c_str());
+		removeFile(filename);
+		return false;
+	}
 	LOG_DEBUG("Parsed %s with %d files", filename.c_str(), (int)files.size());
 	return true;
 }
@@ -475,21 +502,61 @@ bool CFileSystem::parseTorrent(const char* data, int size, IDownload* dl)
 
 bool CFileSystem::dumpSDP(const std::string& filename)
 {
-	std::list<FileData*> files;
-	files.clear();
+	std::list<FileData> files;
 	if (!parseSdp(filename, files))
 		return false;
 	LOG_INFO("md5 (filename in pool)           crc32        size filename");
 	std::list<FileData*>::iterator it;
 	HashMD5 md5;
-	for (it = files.begin(); it != files.end(); ++it) {
-		md5.Set((*it)->md5, sizeof((*it)->md5));
-		LOG_INFO("%s %.8X %8d %s", md5.toString().c_str(), (*it)->crc32,
-			 (*it)->size, (*it)->name.c_str());
+	for (const FileData& fd: files) {
+		md5.Set(fd.md5, sizeof(fd.md5));
+		LOG_INFO("%s %.8X %8d %s", md5.toString().c_str(), fd.crc32,
+		         fd.size, fd.name.c_str());
 	}
 	return true;
 }
 
+bool CFileSystem::validateSDP(const std::string& sdpPath)
+{
+	LOG_DEBUG("CFileSystem::validateSDP() ...");
+	if (!fileExists(sdpPath)){
+		LOG_ERROR("SDP file doesn't exist: %s", sdpPath.c_str());
+		return false;
+	}
+
+	std::list<FileData> files;
+	if (!parseSdp(sdpPath, files)) {// parse downloaded file
+		LOG_ERROR("Removing invalid SDP file: %s", sdpPath.c_str());
+		if (!removeFile(sdpPath)) {
+			LOG_ERROR("Failed removing %s, aborting", sdpPath.c_str());
+			return false;
+		}
+		return false;
+	}
+
+	bool valid = true;
+	for (FileData& fd : files) {
+
+		std::string filePath;
+		HashMD5 fileMd5;
+		fileMd5.Set(fd.md5, sizeof(fd.md5));
+		getPoolFilename(fileMd5.toString(), filePath);
+		if(!fileExists(filePath)) {
+			valid = false;
+			LOG_INFO("Missing file: %s", filePath.c_str());
+		} else if (!fileIsValid(&fd, filePath)) {
+			valid = false;
+			LOG_INFO("Removing invalid file: %s", filePath.c_str());
+			if (!removeFile(filePath)) {
+				LOG_ERROR("Failed removing %s, aborting", filePath.c_str());
+				return false;
+			}
+		}
+	}
+	LOG_DEBUG("CFileSystem::validateSDP() done");
+	return valid;
+}
+
 bool CFileSystem::extractEngine(const std::string& filename,
 				const std::string& version)
 {
