@@ -162,52 +162,38 @@ void Unitsync::PopulateArchiveList()
 	const int numMaps = susynclib().GetMapCount();
 	for (int i = 0; i < numMaps; i++) {
 		std::string name, archivename;
-		unsigned int hash;
 		try {
 			const int count = susynclib().GetMapArchiveCount(i);
 			if (count > 0) {
 				archivename = susynclib().GetMapArchiveName(0);
 			}
 			name = susynclib().GetMapName(i);
-			hash = susynclib().GetMapChecksum(i);
 			//PrefetchMap( name ); // DEBUG
 		} catch (...) {
 			continue;
 		}
-		try {
-			assert(!name.empty());
-			m_maps_list[name] = LSL::Util::ToUIntString(hash);
-			if (!archivename.empty())
-				m_maps_archive_name[name] = archivename;
-			m_map_array.push_back(name);
-		} catch (...) {
-			LslError("Found map with hash collision: %s hash: %d", name.c_str(), hash);
-		}
+		assert(!name.empty());
+		if (!archivename.empty())
+			m_maps_archive_name[name] = archivename;
+		m_map_array.push_back(name);
 		FetchUnitsyncErrors(name);
 	}
 	const int numMods = susynclib().GetPrimaryModCount();
 	for (int i = 0; i < numMods; i++) {
 		std::string name, archivename;
-		unsigned int hash;
 		try {
 			const int count = susynclib().GetPrimaryModArchiveCount(i);
 			if (count > 0) {
 				archivename = susynclib().GetPrimaryModArchive(i);
 			}
 			name = GetGameInfo(i, "name");
-			hash = susynclib().GetPrimaryModChecksumFromName(name);
 		} catch (...) {
 			continue;
 		}
-		try {
-			assert(!name.empty());
-			m_mods_list[name] = LSL::Util::ToUIntString(hash);
-			if (!archivename.empty())
-				m_mods_archive_name[name] = archivename;
-			m_mod_array.push_back(name);
-		} catch (...) {
-			LslError("Found game with hash collision: %s hash: %s", name.c_str(), hash);
-		}
+		assert(!name.empty());
+		if (!archivename.empty())
+			m_mods_archive_name[name] = archivename;
+		m_mod_array.push_back(name);
 		FetchUnitsyncErrors(name);
 	}
 	m_unsorted_mod_array = m_mod_array;
@@ -248,18 +234,31 @@ StringVector Unitsync::GetGameList() const
 	return m_mod_array;
 }
 
-bool Unitsync::GameExists(const std::string& gamename, const std::string& hash) const
+bool Unitsync::GameExists(const std::string& gamename, const std::string& hash)
 {
 	TRY_LOCK(false)
-	LocalArchivesVector::const_iterator itor = m_mods_list.find(gamename);
-	if (itor == m_mods_list.end() || itor->second.empty())
+	LocalArchivesVector::const_iterator itor = m_mods_archive_name.find(gamename);
+	if (itor == m_mods_archive_name.end() || itor->second.empty())
 		return false;
 
 	assert(!itor->second.empty()); //empty hashes are invalid
 
 	if (hash.empty())
 		return true;
-	return itor->second == hash;
+	return GetGameHash(gamename) == hash;
+}
+
+std::string Unitsync::GetGameHash(const std::string& name)
+{
+	LocalArchivesVector::const_iterator itor = m_mods_list.find(name);
+	if (itor != m_mods_list.end()) {
+		return itor->second;
+	}
+	const unsigned int modhash = susynclib().GetPrimaryModChecksumFromName(name);
+	assert(modhash>0);
+	const std::string strhash = LSL::Util::ToUIntString(modhash);
+	m_mods_list[name] = strhash;
+	return strhash;
 }
 
 UnitsyncGame Unitsync::GetGame(const std::string& gamename)
@@ -267,7 +266,9 @@ UnitsyncGame Unitsync::GetGame(const std::string& gamename)
 	UnitsyncGame m;
 	TRY_LOCK(m);
 	m.name = gamename;
-	m.hash = m_mods_list[gamename];
+	m.hash = GetGameHash(gamename);
+	assert(m.hash != "0");
+	assert(!m.hash.empty());
 	return m;
 }
 
@@ -277,7 +278,9 @@ UnitsyncGame Unitsync::GetGame(int index)
 	UnitsyncGame m;
 	TRY_LOCK(m);
 	m.name = m_mod_array[index];
-	m.hash = m_mods_list[m.name];
+	m.hash = GetGameHash(m.name);
+	assert(m.hash != "0");
+	assert(!m.hash.empty());
 	return m;
 }
 
@@ -300,17 +303,31 @@ StringVector Unitsync::GetGameValidMapList(const std::string& gamename) const
 	return ret;
 }
 
-bool Unitsync::MapExists(const std::string& mapname, const std::string& hash) const
+bool Unitsync::MapExists(const std::string& mapname, const std::string& hash)
 {
 	assert(!mapname.empty());
 	TRY_LOCK(false)
-	LocalArchivesVector::const_iterator itor = m_maps_list.find(mapname);
-	if (itor == m_maps_list.end())
+	LocalArchivesVector::const_iterator itor = m_maps_archive_name.find(mapname);
+	if (itor == m_maps_archive_name.end())
 		return false;
 	assert(!itor->second.empty()); //empty hashes are invalid
 	if (hash.empty())
 		return true;
-	return itor->second == hash;
+
+	return GetMapHash(mapname) == hash;
+}
+
+std::string Unitsync::GetMapHash(const std::string& name)
+{
+	LocalArchivesVector::const_iterator itor = m_maps_list.find(name);
+	if (itor != m_maps_list.end()) {
+		return itor->second;
+	}
+	const unsigned int modhash = susynclib().GetMapChecksumFromName(name);
+	assert(modhash > 0);
+	const std::string strhash = LSL::Util::ToUIntString(modhash);
+	m_maps_list[name] = strhash;
+	return strhash;
 }
 
 UnitsyncMap Unitsync::GetMap(int index)
@@ -320,7 +337,7 @@ UnitsyncMap Unitsync::GetMap(int index)
 	if (index < 0)
 		return m;
 	m.name = m_map_array[index];
-	m.hash = m_maps_list[m.name];
+	m.hash = GetMapHash(m.name);
 	m.info = _GetMapInfoEx(m.name);
 	assert(!m.hash.empty());
 	return m;
@@ -411,7 +428,7 @@ UnitsyncMap Unitsync::GetMap(const std::string& mapname)
 		LSL_THROWF(unitsync, "Map does not exist: %s", mapname.c_str());
 	}
 	m.name = m_map_array[i];
-	m.hash = m_maps_list[m.name];
+	m.hash = GetMapHash(mapname);
 	m.info = _GetMapInfoEx(m.name);
 	assert(!m.hash.empty());
 	return m;
@@ -427,6 +444,7 @@ GameOptions Unitsync::GetGameOptions(const std::string& name)
 	if (m_game_gameoptions.find(name) != m_game_gameoptions.end()) {
 		return m_game_gameoptions[name];
 	}
+	GetGameHash(name);
 	const std::string filename = GetGameOptionsPath(name);
 	if (!lslcache.Get(filename, ret)) {
 		PrefetchGame(name);
@@ -455,6 +473,7 @@ StringVector Unitsync::GetSides(const std::string& gamename)
 	if (!GameExists(gamename))
 		return ret;
 	TRY_LOCK(ret);
+	GetGameHash(gamename);
 	const std::string cachefile = GetSidesCachePath(gamename);
 
 	if (!lslcache.Get(cachefile, ret) && (GameExists(gamename))) { // cache file failed, try from lsl
@@ -911,6 +930,7 @@ void Unitsync::PrefetchMap(const std::string& mapname)
 
 
 	FetchUnitsyncErrors(mapname);
+	GetMapHash(mapname);
 
 	const int index = Util::IndexInSequence(m_unsorted_map_array, mapname);
 	ASSERT_EXCEPTION(index >= 0, "Map not found");
@@ -949,6 +969,7 @@ void Unitsync::PrefetchGame(const std::string& gamename)
 {
 	assert(!gamename.empty());
 	susynclib().SetCurrentMod(gamename);
+	GetGameHash(gamename);
 	{
 		int count = susynclib().GetModOptionCount(gamename);
 		GameOptions opt;
