@@ -724,7 +724,10 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		m_se->OnPrivateMessageEx(user, user, params);
 	} else if (cmd == "JOINBATTLE") {
 		const int id = GetIntParam(params);
-		const std::string hash = LSL::Util::MakeHashUnsigned(GetWordParam(params));
+		std::string hash = LSL::Util::MakeHashUnsigned(GetWordParam(params));
+		if (hash == "0") {
+			hash.clear();
+		}
 		m_battle_id = id;
 		m_se->OnJoinedBattle(id, hash);
 		m_se->OnBattleInfoUpdated(m_battle_id);
@@ -985,12 +988,20 @@ void TASServer::SendCmd(const std::string& command, const std::string& param, bo
 		return;
 	}
 
-	if (command != "PING") { //don't log PING
-		if (send_success)
-			wxLogMessage(wxString::Format(_T("sent: %s"), msg.c_str()));
-		else
-			wxLogMessage(wxString::Format(_T("sending: %s failed"), msg.c_str()));
-	}
+	if (command == "PING") return;
+	if (command == "SAY") return;
+	if (command == "SAYEX") return;
+	if (command == "SAYPRIVATE") return;
+	if (command == "SAYPRIVATEEX") return;
+	if (command == "SAYBATTLE") return;
+	if (command == "SAYBATTLEEX") return;
+	if (command == "SAYBATTLEPRIVATE") return;
+	if (command == "SAYBATTLEPRIVATEEX") return;
+
+	if (send_success)
+		wxLogMessage(wxString::Format(_T("sent: %s"), msg.c_str()));
+	else
+		wxLogMessage(wxString::Format(_T("sending: %s failed"), msg.c_str()));
 }
 
 void TASServer::SetRelayIngamePassword(const User& user)
